lodstorage.version — pyLoDStorage documentation

# Source code for lodstorage.version

    """
    Created on 2022-03-06

    @author: wf
    """
    import lodstorage

    class Version(object):
        """
        Version handling for pyLoDStorage
        """

        name = "pylodstorage"
        version = lodstorage.__version__
        date = "2020-09-10"
        updated = "2024-01-28"
        description = "python List of Dict (Table) Storage library"